**flownetpy** is a python package for simulating and analyzing flow networks. 
|today| (Version |release|)

Debsankha Manik <dmanik@nld.ds.mpg.de>
`Max Planck Institute for Dynamics & Self-Organization <http://www.ds.mpg.de/en>`_, Göttingen, Germany

Documentation license
---------------------

|CC| This documentation is licensed under a `Creative Commons Attribution 4.0 International License`_.

.. _Creative Commons Attribution 4.0 International License: http://creativecommons.org/licenses/by/4.0/

.. |CC| image:: _static/cc-by.*
